@@ -34,7 +34,7 @@ LOG = logging.getLogger(__name__)
 
 # Global constants
 THUNDRA_APIKEY_ENV_VAR_NAME = "THUNDRA_APIKEY"
-THUNDRA_AGENT_LOG_DISABLE_VAR_NAME = "THUNDRA_AGENT_LOG_DISABLE"
+THUNDRA_AGENT_LOG_DISABLE_VAR_NAME = "THUNDRA_AGENT_LAMBDA_LOG_DISABLE"
 THUNDRA_APIKEY = os.getenv(THUNDRA_APIKEY_ENV_VAR_NAME)
 
 # Java related constants
