@@ -604,6 +604,9 @@ def lambda_function_name(name_or_arn):
     return parts[6]
 
 
+# TODO: extract ARN utils into separate file!
+
+
 def state_machine_arn(name, account_id=None, region_name=None):
     pattern = "arn:aws:states:%s:%s:stateMachine:%s"
     return _resource_arn(name, pattern, account_id=account_id, region_name=region_name)
@@ -860,6 +863,15 @@ def mock_aws_request_headers(service="dynamodb", region_name=None):
     return headers
 
 
+def inject_region_into_auth_headers(region, headers):
+    auth_header = headers.get("Authorization")
+    if auth_header:
+        regex = r"Credential=([^/]+)/([^/]+)/([^/]+)/"
+        auth_header = re.sub(regex, r"Credential=\1/\2/%s/" % region, auth_header)
+        headers["Authorization"] = auth_header
+    return headers
+
+
 def dynamodb_get_item_raw(request):
     headers = mock_aws_request_headers()
     headers["X-Amz-Target"] = "DynamoDB_20120810.GetItem"
