@@ -256,7 +256,10 @@ class ContainerClient(metaclass=ABCMeta):
 
     @abstractmethod
     def get_container_ip(self, container_name_or_id: str) -> str:
-        """Get the IP address of a given container"""
+        """Get the IP address of a given container
+
+        If container has multiple networks, it will return the IP of the first
+        """
         pass
 
     def get_image_cmd(self, docker_image: str) -> str:
@@ -840,6 +843,83 @@ class Util:
                 else:
                     LOG.debug("File to copy empty, ignoring...")
 
+    @staticmethod
+    def parse_additional_flags(
+        additional_flags: str,
+        env_vars: Dict[str, str] = None,
+        ports: PortMappings = None,
+        mounts: List[Tuple[str, str]] = None,
+    ) -> Tuple[Dict[str, str], PortMappings, List[Tuple[str, str]], Optional[Dict[str, str]]]:
+        """Parses environment, volume and port flags passed as string
+        :param additional_flags: String which contains the flag definitions
+        :param env_vars: Dict with env vars. Will be modified in place.
+        :param ports: PortMapping object. Will be modified in place.
+        :param mounts: List of mount tuples (host_path, container_path). Will be modified in place.
+        :return: A tuple containing the env_vars, ports and mount objects. Will return new objects if respective
+                parameters were None and additional flags contained a flag for that object, the same which are passed
+                otherwise.
+        """
+        cur_state = None
+        extra_hosts = None
+        # TODO Use argparse to simplify this logic
+        for flag in shlex.split(additional_flags):
+            if not cur_state:
+                if flag in ["-v", "--volume"]:
+                    cur_state = "volume"
+                elif flag in ["-p", "--publish"]:
+                    cur_state = "port"
+                elif flag in ["-e", "--env"]:
+                    cur_state = "env"
+                elif flag == "--add-host":
+                    cur_state = "add-host"
+                else:
+                    raise NotImplementedError(
+                        "Flag %s is currently not supported by this docker client."
+                    )
+            else:
+                if cur_state == "volume":
+                    mounts = mounts if mounts is not None else []
+                    mounts.append(tuple(flag.split(":")))
+                elif cur_state == "port":
+                    port_split = flag.split(":")
+                    protocol = "tcp"
+                    if len(port_split) == 2:
+                        host_port, container_port = port_split
+                    elif len(port_split) == 3:
+                        LOG.warning(
+                            "Host part of port mappings are ignored currently in additional flags"
+                        )
+                        _, host_port, container_port = port_split
+                    else:
+                        raise ValueError("Invalid port string provided: %s", flag)
+                    if "/" in container_port:
+                        container_port, protocol = container_port.split("/")
+                    ports = ports if ports is not None else PortMappings()
+                    ports.add(int(host_port), int(container_port), protocol)
+                elif cur_state == "env":
+                    env_split = flag.split("=")
+                    env_vars = env_vars if env_vars is not None else {}
+                    env_vars[env_split[0]] = env_split[1]
+                elif cur_state == "add-host":
+                    extra_hosts = extra_hosts if extra_hosts is not None else {}
+                    hosts_split = flag.split(":")
+                    extra_hosts[hosts_split[0]] = hosts_split[1]
+
+                cur_state = None
+        return env_vars, ports, mounts, extra_hosts
+
+    @staticmethod
+    def convert_mount_list_to_dict(
+        mount_volumes: List[Tuple[str, str]]
+    ) -> Dict[str, Dict[str, str]]:
+        """Converts a List of (host_path, container_path) tuples to a Dict suitable as volume argument for docker sdk"""
+        return dict(
+            map(
+                lambda paths: (str(paths[0]), {"bind": paths[1], "mode": "rw"}),
+                mount_volumes,
+            )
+        )
+
 
 class SdkDockerClient(ContainerClient):
     """Class for managing docker using the python docker sdk"""
@@ -875,62 +955,6 @@ class SdkDockerClient(ContainerClient):
                 raise ContainerException("Invalid frame type when reading from socket")
         return stdout, stderr
 
-    def _parse_additional_flags(
-        self,
-        additional_flags: str,
-        env_vars: Dict[str, str],
-        ports: PortMappings,
-        mounts: List[Tuple[str, str]],
-    ) -> Tuple[Dict[str, str], PortMappings, List[Tuple[str, str]]]:
-        """Parses environment, volume and port flags passed as string
-        :param additional_flags: String which contains the flag definitions
-        :param env_vars: Dict with env vars. Will be modified in place.
-        :param ports: PortMapping object. Will be modified in place.
-        :param mounts: List of mount tuples. Will be modified in place.
-        :return: A tuple containing the env_vars, ports and mount objects. Will return new objects if respective
-                parameters were None and additional flags contained a flag for that object, the same which are passed
-                otherwise.
-        """
-        cur_state = None
-        for flag in shlex.split(additional_flags):
-            if not cur_state:
-                if flag in ["-v", "--volume"]:
-                    cur_state = "volume"
-                elif flag in ["-p", "--publish"]:
-                    cur_state = "port"
-                elif flag in ["-e", "--env"]:
-                    cur_state = "env"
-                else:
-                    raise NotImplementedError(
-                        "Flag %s is currently not supported by this docker client."
-                    )
-            else:
-                if cur_state == "volume":
-                    mounts = mounts if mounts is not None else []
-                    mounts.append(tuple(flag.split(":")))
-                elif cur_state == "port":
-                    port_split = flag.split(":")
-                    protocol = "tcp"
-                    if len(port_split) == 2:
-                        host_port, container_port = port_split
-                    elif len(port_split) == 3:
-                        LOG.warning(
-                            "Host part of port mappings are ignored currently in additional flags"
-                        )
-                        _, host_port, container_port = port_split
-                    else:
-                        raise ValueError("Invalid port string provided: %s", flag)
-                    if "/" in container_port:
-                        container_port, protocol = container_port.split("/")
-                    ports = ports if ports is not None else PortMappings()
-                    ports.add(int(host_port), int(container_port), protocol)
-                elif cur_state == "env":
-                    env_split = flag.split("=")
-                    env_vars = env_vars if env_vars is not None else {}
-                    env_vars[env_split[0]] = env_split[1]
-                cur_state = None
-        return env_vars, ports, mounts
-
     def _container_path_info(self, container: Container, container_path: str):
         """
         Get information about a path in the given container
@@ -1108,7 +1132,11 @@ class SdkDockerClient(ContainerClient):
             raise ContainerException()
 
     def get_container_ip(self, container_name_or_id: str) -> str:
-        return self.inspect_container(container_name_or_id)["NetworkSettings"]["IPAddress"]
+        networks = self.inspect_container(container_name_or_id)["NetworkSettings"]["Networks"]
+        network_names = list(networks)
+        if len(network_names) > 1:
+            LOG.info("Container has more than one assigned network. Picking the first one...")
+        return networks[network_names[0]]["IPAddress"]
 
     def has_docker(self) -> bool:
         try:
@@ -1188,8 +1216,9 @@ class SdkDockerClient(ContainerClient):
         additional_flags: Optional[str] = None,
     ) -> str:
         LOG.debug("Creating container with image: %s", image_name)
+        extra_hosts = None
         if additional_flags:
-            env_vars, ports, mount_volumes = self._parse_additional_flags(
+            env_vars, ports, mount_volumes, extra_hosts = Util.parse_additional_flags(
                 additional_flags, env_vars, ports, mount_volumes
             )
         try:
@@ -1202,12 +1231,7 @@ class SdkDockerClient(ContainerClient):
                 kwargs["ports"] = ports.to_dict()
             mounts = None
             if mount_volumes:
-                mounts = dict(
-                    map(
-                        lambda paths: (str(paths[0]), {"bind": paths[1], "mode": "rw"}),
-                        mount_volumes,
-                    )
-                )
+                mounts = Util.convert_mount_list_to_dict(mount_volumes)
 
             def create_container():
                 return self.client().containers.create(
@@ -1223,6 +1247,7 @@ class SdkDockerClient(ContainerClient):
                     user=user,
                     network=network,
                     volumes=mounts,
+                    extra_hosts=extra_hosts,
                     **kwargs,
                 )
 
