@@ -16,7 +16,7 @@ from localstack.config import DATA_DIR, is_env_not_false, is_env_true
 from localstack.services.generic_proxy import ProxyListener
 from localstack.utils.aws import aws_stack
 from localstack.utils.bootstrap import is_api_enabled
-from localstack.utils.common import to_bytes, to_str
+from localstack.utils.common import chmod_r, to_bytes, to_str
 
 USE_SINGLE_DUMP_FILE = is_env_not_false("PERSISTENCE_SINGLE_FILE")
 
@@ -225,6 +225,7 @@ def save_startup_info():
     except IOError as e:
         LOG.error("could not save startup info: %s", e)
 
+    chmod_r(file_path, 0o777)
     return info
 
 
